==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/IdentityProvidersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.IdentityProvidersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * The configuration settings of each of the identity providers used to configure ContainerApp Service Authentication/Authorization.
 * @property apple The configuration settings of the Apple provider.
 * @property azureActiveDirectory The configuration settings of the Azure Active directory provider.
 * @property azureStaticWebApps The configuration settings of the Azure Static Web Apps provider.
 * @property customOpenIdConnectProviders The map of the name of the alias of each custom Open ID Connect provider to the
 * configuration settings of the custom Open ID Connect provider.
 * @property facebook The configuration settings of the Facebook provider.
 * @property gitHub The configuration settings of the GitHub provider.
 * @property google The configuration settings of the Google provider.
 * @property twitter The configuration settings of the Twitter provider.
 */
public data class IdentityProvidersArgs(
    public val apple: Output<AppleArgs>? = null,
    public val azureActiveDirectory: Output<AzureActiveDirectoryArgs>? = null,
    public val azureStaticWebApps: Output<AzureStaticWebAppsArgs>? = null,
    public val customOpenIdConnectProviders: Output<Map<String, CustomOpenIdConnectProviderArgs>>? =
        null,
    public val facebook: Output<FacebookArgs>? = null,
    public val gitHub: Output<GitHubArgs>? = null,
    public val google: Output<GoogleArgs>? = null,
    public val twitter: Output<TwitterArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.IdentityProvidersArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.IdentityProvidersArgs =
        com.pulumi.azurenative.app.inputs.IdentityProvidersArgs.builder()
            .apple(apple?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .azureActiveDirectory(
                azureActiveDirectory?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .azureStaticWebApps(
                azureStaticWebApps?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customOpenIdConnectProviders(
                customOpenIdConnectProviders?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.key.to(args0.value.let({ args0 -> args0.toJava() })) }).toMap()
                }),
            )
            .facebook(facebook?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gitHub(gitHub?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .google(google?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .twitter(twitter?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [IdentityProvidersArgs].
 */
@PulumiTagMarker
public class IdentityProvidersArgsBuilder internal constructor() {
    private var apple: Output<AppleArgs>? = null

    private var azureActiveDirectory: Output<AzureActiveDirectoryArgs>? = null

    private var azureStaticWebApps: Output<AzureStaticWebAppsArgs>? = null

    private var customOpenIdConnectProviders: Output<Map<String, CustomOpenIdConnectProviderArgs>>? =
        null

    private var facebook: Output<FacebookArgs>? = null

    private var gitHub: Output<GitHubArgs>? = null

    private var google: Output<GoogleArgs>? = null

    private var twitter: Output<TwitterArgs>? = null

    /**
     * @param value The configuration settings of the Apple provider.
     */
    @JvmName("fjmixulvofsdxaqd")
    public suspend fun apple(`value`: Output<AppleArgs>) {
        this.apple = value
    }

    /**
     * @param value The configuration settings of the Azure Active directory provider.
     */
    @JvmName("felffqodoadtnjqd")
    public suspend fun azureActiveDirectory(`value`: Output<AzureActiveDirectoryArgs>) {
        this.azureActiveDirectory = value
    }

    /**
     * @param value The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("mqlclcrsimcnluel")
    public suspend fun azureStaticWebApps(`value`: Output<AzureStaticWebAppsArgs>) {
        this.azureStaticWebApps = value
    }

    /**
     * @param value The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("tkubespssspnjlir")
    public suspend
    fun customOpenIdConnectProviders(`value`: Output<Map<String, CustomOpenIdConnectProviderArgs>>) {
        this.customOpenIdConnectProviders = value
    }

    /**
     * @param value The configuration settings of the Facebook provider.
     */
    @JvmName("uyslcrnkmorfvtid")
    public suspend fun facebook(`value`: Output<FacebookArgs>) {
        this.facebook = value
    }

    /**
     * @param value The configuration settings of the GitHub provider.
     */
    @JvmName("wwcbppoldeyosrhr")
    public suspend fun gitHub(`value`: Output<GitHubArgs>) {
        this.gitHub = value
    }

    /**
     * @param value The configuration settings of the Google provider.
     */
    @JvmName("pavryryphxebnwik")
    public suspend fun google(`value`: Output<GoogleArgs>) {
        this.google = value
    }

    /**
     * @param value The configuration settings of the Twitter provider.
     */
    @JvmName("wvlwvtuencjhruea")
    public suspend fun twitter(`value`: Output<TwitterArgs>) {
        this.twitter = value
    }

    /**
     * @param value The configuration settings of the Apple provider.
     */
    @JvmName("yuktlxqkjyldtepa")
    public suspend fun apple(`value`: AppleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apple = mapped
    }

    /**
     * @param argument The configuration settings of the Apple provider.
     */
    @JvmName("nlispdgqagxgsvpf")
    public suspend fun apple(argument: suspend AppleArgsBuilder.() -> Unit) {
        val toBeMapped = AppleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apple = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active directory provider.
     */
    @JvmName("rtbtxhsfsoywnddi")
    public suspend fun azureActiveDirectory(`value`: AzureActiveDirectoryArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureActiveDirectory = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active directory provider.
     */
    @JvmName("mcpcbyuyinmhilqp")
    public suspend
    fun azureActiveDirectory(argument: suspend AzureActiveDirectoryArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureActiveDirectory = mapped
    }

    /**
     * @param value The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("ovcnoqsufyftilhn")
    public suspend fun azureStaticWebApps(`value`: AzureStaticWebAppsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureStaticWebApps = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("ckomcxtlvsnqsjpn")
    public suspend
    fun azureStaticWebApps(argument: suspend AzureStaticWebAppsArgsBuilder.() -> Unit) {
        val toBeMapped = AzureStaticWebAppsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureStaticWebApps = mapped
    }

    /**
     * @param value The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("qsuypmmbqkmfcogw")
    public suspend
    fun customOpenIdConnectProviders(`value`: Map<String, CustomOpenIdConnectProviderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param argument The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("kyegcvqblmglqjmh")
    public suspend fun customOpenIdConnectProviders(
        vararg
        argument: Pair<String, suspend CustomOpenIdConnectProviderArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                CustomOpenIdConnectProviderArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param values The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("vqqkhoyiwiehqcsc")
    public fun customOpenIdConnectProviders(
        vararg
        values: Pair<String, CustomOpenIdConnectProviderArgs>,
    ) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param value The configuration settings of the Facebook provider.
     */
    @JvmName("okubwpjygihajnpp")
    public suspend fun facebook(`value`: FacebookArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.facebook = mapped
    }

    /**
     * @param argument The configuration settings of the Facebook provider.
     */
    @JvmName("oubkqkvgfyluswcb")
    public suspend fun facebook(argument: suspend FacebookArgsBuilder.() -> Unit) {
        val toBeMapped = FacebookArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.facebook = mapped
    }

    /**
     * @param value The configuration settings of the GitHub provider.
     */
    @JvmName("klrooelnkrfhnitr")
    public suspend fun gitHub(`value`: GitHubArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gitHub = mapped
    }

    /**
     * @param argument The configuration settings of the GitHub provider.
     */
    @JvmName("lhjxbvslsidcuybu")
    public suspend fun gitHub(argument: suspend GitHubArgsBuilder.() -> Unit) {
        val toBeMapped = GitHubArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gitHub = mapped
    }

    /**
     * @param value The configuration settings of the Google provider.
     */
    @JvmName("jbpceiegymhgqxmv")
    public suspend fun google(`value`: GoogleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.google = mapped
    }

    /**
     * @param argument The configuration settings of the Google provider.
     */
    @JvmName("qpamabvscpnmuihe")
    public suspend fun google(argument: suspend GoogleArgsBuilder.() -> Unit) {
        val toBeMapped = GoogleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.google = mapped
    }

    /**
     * @param value The configuration settings of the Twitter provider.
     */
    @JvmName("qysrfiyqxfqnulat")
    public suspend fun twitter(`value`: TwitterArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.twitter = mapped
    }

    /**
     * @param argument The configuration settings of the Twitter provider.
     */
    @JvmName("oajcxcvgwjvvqpyc")
    public suspend fun twitter(argument: suspend TwitterArgsBuilder.() -> Unit) {
        val toBeMapped = TwitterArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.twitter = mapped
    }

    internal fun build(): IdentityProvidersArgs = IdentityProvidersArgs(
        apple = apple,
        azureActiveDirectory = azureActiveDirectory,
        azureStaticWebApps = azureStaticWebApps,
        customOpenIdConnectProviders = customOpenIdConnectProviders,
        facebook = facebook,
        gitHub = gitHub,
        google = google,
        twitter = twitter,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/IdentityProvidersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.IdentityProvidersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * The configuration settings of each of the identity providers used to configure ContainerApp Service Authentication/Authorization.
 * @property apple The configuration settings of the Apple provider.
 * @property azureActiveDirectory The configuration settings of the Azure Active directory provider.
 * @property azureStaticWebApps The configuration settings of the Azure Static Web Apps provider.
 * @property customOpenIdConnectProviders The map of the name of the alias of each custom Open ID Connect provider to the
 * configuration settings of the custom Open ID Connect provider.
 * @property facebook The configuration settings of the Facebook provider.
 * @property gitHub The configuration settings of the GitHub provider.
 * @property google The configuration settings of the Google provider.
 * @property twitter The configuration settings of the Twitter provider.
 */
public data class IdentityProvidersArgs(
    public val apple: Output<AppleArgs>? = null,
    public val azureActiveDirectory: Output<AzureActiveDirectoryArgs>? = null,
    public val azureStaticWebApps: Output<AzureStaticWebAppsArgs>? = null,
    public val customOpenIdConnectProviders: Output<Map<String, CustomOpenIdConnectProviderArgs>>? =
        null,
    public val facebook: Output<FacebookArgs>? = null,
    public val gitHub: Output<GitHubArgs>? = null,
    public val google: Output<GoogleArgs>? = null,
    public val twitter: Output<TwitterArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.IdentityProvidersArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.IdentityProvidersArgs =
        com.pulumi.azurenative.app.inputs.IdentityProvidersArgs.builder()
            .apple(apple?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .azureActiveDirectory(
                azureActiveDirectory?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .azureStaticWebApps(
                azureStaticWebApps?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customOpenIdConnectProviders(
                customOpenIdConnectProviders?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.key.to(args0.value.let({ args0 -> args0.toJava() })) }).toMap()
                }),
            )
            .facebook(facebook?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .gitHub(gitHub?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .google(google?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .twitter(twitter?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [IdentityProvidersArgs].
 */
@PulumiTagMarker
public class IdentityProvidersArgsBuilder internal constructor() {
    private var apple: Output<AppleArgs>? = null

    private var azureActiveDirectory: Output<AzureActiveDirectoryArgs>? = null

    private var azureStaticWebApps: Output<AzureStaticWebAppsArgs>? = null

    private var customOpenIdConnectProviders: Output<Map<String, CustomOpenIdConnectProviderArgs>>? =
        null

    private var facebook: Output<FacebookArgs>? = null

    private var gitHub: Output<GitHubArgs>? = null

    private var google: Output<GoogleArgs>? = null

    private var twitter: Output<TwitterArgs>? = null

    /**
     * @param value The configuration settings of the Apple provider.
     */
    @JvmName("bretrxdaqanpthaj")
    public suspend fun apple(`value`: Output<AppleArgs>) {
        this.apple = value
    }

    /**
     * @param value The configuration settings of the Azure Active directory provider.
     */
    @JvmName("lccrojphwpigycjj")
    public suspend fun azureActiveDirectory(`value`: Output<AzureActiveDirectoryArgs>) {
        this.azureActiveDirectory = value
    }

    /**
     * @param value The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("gxyytfodlbgugulu")
    public suspend fun azureStaticWebApps(`value`: Output<AzureStaticWebAppsArgs>) {
        this.azureStaticWebApps = value
    }

    /**
     * @param value The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("uavgxwufhrjkknhv")
    public suspend
    fun customOpenIdConnectProviders(`value`: Output<Map<String, CustomOpenIdConnectProviderArgs>>) {
        this.customOpenIdConnectProviders = value
    }

    /**
     * @param value The configuration settings of the Facebook provider.
     */
    @JvmName("xlskkjddoyetorum")
    public suspend fun facebook(`value`: Output<FacebookArgs>) {
        this.facebook = value
    }

    /**
     * @param value The configuration settings of the GitHub provider.
     */
    @JvmName("nftmaxmpxlyexnis")
    public suspend fun gitHub(`value`: Output<GitHubArgs>) {
        this.gitHub = value
    }

    /**
     * @param value The configuration settings of the Google provider.
     */
    @JvmName("vgdkesluxfjqtuov")
    public suspend fun google(`value`: Output<GoogleArgs>) {
        this.google = value
    }

    /**
     * @param value The configuration settings of the Twitter provider.
     */
    @JvmName("qxnhdbdyexguevny")
    public suspend fun twitter(`value`: Output<TwitterArgs>) {
        this.twitter = value
    }

    /**
     * @param value The configuration settings of the Apple provider.
     */
    @JvmName("vfppehvltqoqmmxw")
    public suspend fun apple(`value`: AppleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apple = mapped
    }

    /**
     * @param argument The configuration settings of the Apple provider.
     */
    @JvmName("gpoptregwxqdkgoe")
    public suspend fun apple(argument: suspend AppleArgsBuilder.() -> Unit) {
        val toBeMapped = AppleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.apple = mapped
    }

    /**
     * @param value The configuration settings of the Azure Active directory provider.
     */
    @JvmName("lqpgokjtoddtpfgh")
    public suspend fun azureActiveDirectory(`value`: AzureActiveDirectoryArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureActiveDirectory = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Active directory provider.
     */
    @JvmName("ubegcafodomokhoe")
    public suspend
    fun azureActiveDirectory(argument: suspend AzureActiveDirectoryArgsBuilder.() -> Unit) {
        val toBeMapped = AzureActiveDirectoryArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureActiveDirectory = mapped
    }

    /**
     * @param value The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("tclnacpiwftgmdhd")
    public suspend fun azureStaticWebApps(`value`: AzureStaticWebAppsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureStaticWebApps = mapped
    }

    /**
     * @param argument The configuration settings of the Azure Static Web Apps provider.
     */
    @JvmName("ycxokdxktgtfwopn")
    public suspend
    fun azureStaticWebApps(argument: suspend AzureStaticWebAppsArgsBuilder.() -> Unit) {
        val toBeMapped = AzureStaticWebAppsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureStaticWebApps = mapped
    }

    /**
     * @param value The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("gvevroeiscwahrdk")
    public suspend
    fun customOpenIdConnectProviders(`value`: Map<String, CustomOpenIdConnectProviderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param argument The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("hjdcpsotctunchxt")
    public suspend fun customOpenIdConnectProviders(
        vararg
        argument: Pair<String, suspend CustomOpenIdConnectProviderArgsBuilder.() -> Unit>,
    ) {
        val toBeMapped = argument.toList().map { (left, right) ->
            left to
                CustomOpenIdConnectProviderArgsBuilder().applySuspend { right() }.build()
        }.toMap()
        val mapped = of(toBeMapped)
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param values The map of the name of the alias of each custom Open ID Connect provider to the
     * configuration settings of the custom Open ID Connect provider.
     */
    @JvmName("sxnudenocbvtfnhy")
    public fun customOpenIdConnectProviders(
        vararg
        values: Pair<String, CustomOpenIdConnectProviderArgs>,
    ) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customOpenIdConnectProviders = mapped
    }

    /**
     * @param value The configuration settings of the Facebook provider.
     */
    @JvmName("csmvckeivthjefws")
    public suspend fun facebook(`value`: FacebookArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.facebook = mapped
    }

    /**
     * @param argument The configuration settings of the Facebook provider.
     */
    @JvmName("fmdrqyttrmdefsum")
    public suspend fun facebook(argument: suspend FacebookArgsBuilder.() -> Unit) {
        val toBeMapped = FacebookArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.facebook = mapped
    }

    /**
     * @param value The configuration settings of the GitHub provider.
     */
    @JvmName("ktteyxowtdodscfy")
    public suspend fun gitHub(`value`: GitHubArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gitHub = mapped
    }

    /**
     * @param argument The configuration settings of the GitHub provider.
     */
    @JvmName("fpwncyacnxilsdjq")
    public suspend fun gitHub(argument: suspend GitHubArgsBuilder.() -> Unit) {
        val toBeMapped = GitHubArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gitHub = mapped
    }

    /**
     * @param value The configuration settings of the Google provider.
     */
    @JvmName("sagbdutiahfkhddj")
    public suspend fun google(`value`: GoogleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.google = mapped
    }

    /**
     * @param argument The configuration settings of the Google provider.
     */
    @JvmName("ottamnxgxhweeryg")
    public suspend fun google(argument: suspend GoogleArgsBuilder.() -> Unit) {
        val toBeMapped = GoogleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.google = mapped
    }

    /**
     * @param value The configuration settings of the Twitter provider.
     */
    @JvmName("iyjtxrcnaualqnvq")
    public suspend fun twitter(`value`: TwitterArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.twitter = mapped
    }

    /**
     * @param argument The configuration settings of the Twitter provider.
     */
    @JvmName("rsijsyklvfoqfkse")
    public suspend fun twitter(argument: suspend TwitterArgsBuilder.() -> Unit) {
        val toBeMapped = TwitterArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.twitter = mapped
    }

    internal fun build(): IdentityProvidersArgs = IdentityProvidersArgs(
        apple = apple,
        azureActiveDirectory = azureActiveDirectory,
        azureStaticWebApps = azureStaticWebApps,
        customOpenIdConnectProviders = customOpenIdConnectProviders,
        facebook = facebook,
        gitHub = gitHub,
        google = google,
        twitter = twitter,
    )
}
